@@ -124,39 +124,40 @@ class Specification:
         implicit_count = 0
         for tag in self.root.iter(): # iterate down tree
             # Grab most recent section heading and link
-            if tag.tag in ['{http://www.w3.org/1999/xhtml}h2', '{http://www.w3.org/1999/xhtml}h3']:
-                if tag.get('class') != 'title':
-                    continue
-                #print "Found heading %s" % (tag.tag)
+            if tag.tag in ['h2', 'h3', 'h4']:
+                #if tag.get('class') != 'title':
+                #    continue
+                print "Found heading %s" % (tag.tag)
                 prev_heading = "".join(tag.itertext())
                 # Insert a space between heading number & title
                 sh_list = prev_heading.rsplit('.', 1)
                 prev_heading = '. '.join(sh_list)
-                prev_link = tag[0].get('id')
-                #print "Set prev_heading %s to have link of %s" % (prev_heading.encode("ascii", "ignore"), prev_link.encode("ascii", "ignore"))
-            elif tag.tag == '{http://www.w3.org/1999/xhtml}a': # grab any intermediate links
+                prev_link = tag.get('id')
+                print "Set prev_heading %s to have link of %s" % (prev_heading.encode("ascii", "ignore"), prev_link.encode("ascii", "ignore"))
+            elif tag.tag == 'a': # grab any intermediate links
                 if tag.get('id') != None:
                     prev_link = tag.get('id')
                     #print "Updated prev link to %s" % (prev_link)
-            elif tag.tag == '{http://www.w3.org/1999/xhtml}pre' and tag.get('class') == 'programlisting':
+            elif tag.tag == 'div' and tag.get('class') == 'listingblock':
                 # Check and see if this is API function
                 code_text = "".join(tag.itertext()).replace('\n', '')
                 code_text_list = code_text.split()
                 if len(code_text_list) > 1 and code_text_list[1].startswith('vk'):
                     api_function = code_text_list[1].strip('(')
-                    #print "Found API function: %s" % (api_function)
-            elif tag.tag == '{http://www.w3.org/1999/xhtml}div' and tag.get('class') == 'sidebar':
+                    print "Found API function: %s" % (api_function)
+            #elif tag.tag == '{http://www.w3.org/1999/xhtml}div' and tag.get('class') == 'sidebar':
+            elif tag.tag == 'div' and tag.get('class') == 'content':
                 # parse down sidebar to check for valid usage cases
                 valid_usage = False
                 implicit = False
                 for elem in tag.iter():
-                    if elem.tag == '{http://www.w3.org/1999/xhtml}strong' and None != elem.text and 'Valid Usage' in elem.text:
+                    if elem.tag == 'div' and None != elem.text and 'Valid Usage' in elem.text:
                         valid_usage = True
                         if '(Implicit)' in elem.text:
                             implicit = True
                         else:
                             implicit = False
-                    elif valid_usage and elem.tag == '{http://www.w3.org/1999/xhtml}li': # grab actual valid usage requirements
+                    elif valid_usage and elem.tag == 'li': # grab actual valid usage requirements
                         error_msg_str = "%s '%s' which states '%s' (%s#%s)" % (error_msg_prefix, prev_heading, "".join(elem.itertext()).replace('\n', ''), spec_url, prev_link)
                         # Some txt has multiple spaces so split on whitespace and join w/ single space
                         error_msg_str = " ".join(error_msg_str.split())
@@ -181,18 +182,22 @@ class Specification:
         file_contents = []
         file_contents.append(self.copyright)
         file_contents.append('\n#pragma once')
-        file_contents.append('#include <unordered_map>')
+        file_contents.append('\n// Disable auto-formatting for generated file')
+        file_contents.append('// clang-format off')
+        file_contents.append('\n#include <unordered_map>')
         file_contents.append('\n// enum values for unique validation error codes')
         file_contents.append('//  Corresponding validation error message for each enum is given in the mapping table below')
         file_contents.append('//  When a given error occurs, these enum values should be passed to the as the messageCode')
         file_contents.append('//  parameter to the PFN_vkDebugReportCallbackEXT function')
         enum_decl = ['enum UNIQUE_VALIDATION_ERROR_CODE {\n    VALIDATION_ERROR_UNDEFINED = -1,']
         error_string_map = ['static std::unordered_map<int, char const *const> validation_error_map{']
+        enum_value = 0
         for enum in sorted(self.val_error_dict):
             #print "Header enum is %s" % (enum)
-            enum_decl.append('    %s = %d,' % (enum, int(enum.split('_')[-1])))
+            enum_value = int(enum.split('_')[-1])
+            enum_decl.append('    %s = %d,' % (enum, enum_value))
             error_string_map.append('    {%s, "%s"},' % (enum, self.val_error_dict[enum]['error_msg']))
-        enum_decl.append('    %sMAX_ENUM = %d,' % (validation_error_enum_name, int(enum.split('_')[-1]) + 1))
+        enum_decl.append('    %sMAX_ENUM = %d,' % (validation_error_enum_name, enum_value + 1))
         enum_decl.append('};')
         error_string_map.append('};\n')
         file_contents.extend(enum_decl)
@@ -233,14 +238,14 @@ class Specification:
         db_lines.append("# The format of the lines is:")
         db_lines.append("# <error_enum>%s<check_implemented>%s<testname>%s<api>%s<errormsg>%s<note>" % (self.delimiter, self.delimiter, self.delimiter, self.delimiter, self.delimiter))
         db_lines.append("# error_enum: Unique error enum for this check of format %s<uniqueid>" % validation_error_enum_name)
-        db_lines.append("# check_implemented: 'Y' if check has been implemented in layers, 'U' for unknown, or 'N' for not implemented")
+        db_lines.append("# check_implemented: 'Y' if check has been implemented in layers, or 'N' for not implemented")
         db_lines.append("# testname: Name of validation test for this check, 'Unknown' for unknown, or 'None' if not implmented")
         db_lines.append("# api: Vulkan API function that this check is related to")
         db_lines.append("# errormsg: The unique error message for this check that includes spec language and link")
         db_lines.append("# note: Free txt field with any custom notes related to the check in question")
         for enum in sorted(self.val_error_dict):
-            # Default to unknown if check or test are implemented, then update below if appropriate
-            implemented = 'U'
+            # Default check/test implementation status to N/Unknown, then update below if appropriate
+            implemented = 'N'
             testname = 'Unknown'
             note = ''
             implicit = self.val_error_dict[enum]['implicit']
@@ -569,4 +574,4 @@ if __name__ == "__main__":
 #<em class="parameter"><code>flags</code></em> <span class="normative">must</span> be <code class="literal">0</code>
 #</li><li class="listitem">
 #<em class="parameter"><code>pQueueCreateInfos</code></em> <span class="normative">must</span> be a pointer to an array of <em class="parameter"><code>queueCreateInfoCount</code></em> valid <code class="code">VkDeviceQueueCreateInfo</code> structures
-#</li>
\ No newline at end of file
+#</li>
