@@ -21,26 +21,27 @@
  * Author: Tobin Ehlis <tobin@lunarg.com>
  * Author: Mark Lobodzinski <mark@lunarg.com>
  **************************************************************************/
-#include <fstream>
-#include <string>
-#include <map>
-#include <string.h>
-#include <vulkan/vk_layer.h>
-#include <iostream>
 #include "vk_layer_config.h"
 #include "vulkan/vk_sdk_platform.h"
+#include <fstream>
+#include <iostream>
+#include <map>
+#include <string.h>
+#include <string>
+#include <sys/stat.h>
+#include <vulkan/vk_layer.h>
 
 #define MAX_CHARS_PER_LINE 4096
 
 class ConfigFile {
-  public:
+   public:
     ConfigFile();
     ~ConfigFile();
 
     const char *getOption(const std::string &_option);
     void setOption(const std::string &_option, const std::string &_val);
 
-  private:
+   private:
     bool m_fileIsParsed;
     std::map<std::string, std::string> m_valueMap;
 
@@ -49,6 +50,25 @@ class ConfigFile {
 
 static ConfigFile g_configFileObj;
 
+std::string getEnvironment(const char *variable) {
+#if !defined(__ANDROID__) && !defined(_WIN32)
+    const char *output = getenv(variable);
+    return output == NULL ? "" : output;
+#elif defined(_WIN32)
+    int size = GetEnvironmentVariable(variable, NULL, 0);
+    if (size == 0) {
+        return "";
+    }
+    char *buffer = new char[size];
+    GetEnvironmentVariable(variable, buffer, size);
+    std::string output = buffer;
+    delete[] buffer;
+    return output;
+#else
+    return "";
+#endif
+}
+
 const char *getLayerOption(const char *_option) { return g_configFileObj.getOption(_option); }
 
 // If option is NULL or stdout, return stdout, otherwise try to open option
@@ -78,7 +98,6 @@ VkFlags GetLayerOptionFlags(std::string _option, std::unordered_map<std::string,
     std::string option_list = g_configFileObj.getOption(_option.c_str());
 
     while (option_list.length() != 0) {
-
         // Find length of option string
         std::size_t option_length = option_list.find(",");
         if (option_length == option_list.npos) {
@@ -120,23 +139,33 @@ ConfigFile::ConfigFile() : m_fileIsParsed(false) {
     m_valueMap["lunarg_parameter_validation.report_flags"] = "error";
     m_valueMap["lunarg_swapchain.report_flags"] = "error";
     m_valueMap["google_threading.report_flags"] = "error";
+    m_valueMap["google_unique_objects.report_flags"] = "error";
 
 #ifdef WIN32
     // For Windows, enable message logging AND OutputDebugString
-    m_valueMap["lunarg_core_validation.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
-    m_valueMap["lunarg_image.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
-    m_valueMap["lunarg_object_tracker.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
-    m_valueMap["lunarg_parameter_validation.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
-    m_valueMap["lunarg_swapchain.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
-    m_valueMap["google_threading.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
-#else  // WIN32
+    m_valueMap["lunarg_core_validation.debug_action"] =
+        "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
+    m_valueMap["lunarg_image.debug_action"] =
+        "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
+    m_valueMap["lunarg_object_tracker.debug_action"] =
+        "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
+    m_valueMap["lunarg_parameter_validation.debug_action"] =
+        "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
+    m_valueMap["lunarg_swapchain.debug_action"] =
+        "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
+    m_valueMap["google_threading.debug_action"] =
+        "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
+    m_valueMap["google_unique_objects.debug_action"] =
+        "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG,VK_DBG_LAYER_ACTION_DEBUG_OUTPUT";
+#else   // WIN32
     m_valueMap["lunarg_core_validation.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG";
     m_valueMap["lunarg_image.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG";
     m_valueMap["lunarg_object_tracker.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG";
     m_valueMap["lunarg_parameter_validation.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG";
     m_valueMap["lunarg_swapchain.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG";
     m_valueMap["google_threading.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG";
-#endif // WIN32
+    m_valueMap["google_unique_objects.debug_action"] = "VK_DBG_LAYER_ACTION_DEFAULT,VK_DBG_LAYER_ACTION_LOG_MSG";
+#endif  // WIN32
 
     m_valueMap["lunarg_core_validation.log_filename"] = "stdout";
     m_valueMap["lunarg_image.log_filename"] = "stdout";
@@ -144,6 +173,7 @@ ConfigFile::ConfigFile() : m_fileIsParsed(false) {
     m_valueMap["lunarg_parameter_validation.log_filename"] = "stdout";
     m_valueMap["lunarg_swapchain.log_filename"] = "stdout";
     m_valueMap["google_threading.log_filename"] = "stdout";
+    m_valueMap["google_unique_objects.log_filename"] = "stdout";
 }
 
 ConfigFile::~ConfigFile() {}
@@ -151,7 +181,19 @@ ConfigFile::~ConfigFile() {}
 const char *ConfigFile::getOption(const std::string &_option) {
     std::map<std::string, std::string>::const_iterator it;
     if (!m_fileIsParsed) {
-        parseFile("vk_layer_settings.txt");
+        std::string envPath = getEnvironment("VK_LAYER_SETTINGS_PATH");
+
+        // If the path exists use it, else use vk_layer_settings
+        struct stat info;
+        if (stat(envPath.c_str(), &info) == 0) {
+            // If this is a directory, look for vk_layer_settings within the directory
+            if (info.st_mode & S_IFDIR) {
+                envPath += "/vk_layer_settings.txt";
+            }
+            parseFile(envPath.c_str());
+        } else {
+            parseFile("vk_layer_settings.txt");
+        }
     }
 
     if ((it = m_valueMap.find(_option)) == m_valueMap.end())
@@ -162,7 +204,19 @@ const char *ConfigFile::getOption(const std::string &_option) {
 
 void ConfigFile::setOption(const std::string &_option, const std::string &_val) {
     if (!m_fileIsParsed) {
-        parseFile("vk_layer_settings.txt");
+        std::string envPath = getEnvironment("VK_LAYER_SETTINGS_PATH");
+
+        // If the path exists use it, else use vk_layer_settings
+        struct stat info;
+        if (stat(envPath.c_str(), &info) == 0) {
+            // If this is a directory, look for vk_layer_settings within the directory
+            if (info.st_mode & S_IFDIR) {
+                envPath += "/vk_layer_settings.txt";
+            }
+            parseFile(envPath.c_str());
+        } else {
+            parseFile("vk_layer_settings.txt");
+        }
     }
 
     m_valueMap[_option] = _val;
@@ -179,7 +233,6 @@ void ConfigFile::parseFile(const char *filename) {
         return;
     }
 
-
     // read tokens from the file and form option, value pairs
     file.getline(buf, MAX_CHARS_PER_LINE);
     while (!file.eof()) {
@@ -190,8 +243,7 @@ void ConfigFile::parseFile(const char *filename) {
 
         // discard any comments delimited by '#' in the line
         pComment = strchr(buf, '#');
-        if (pComment)
-            *pComment = '\0';
+        if (pComment) *pComment = '\0';
 
         if (sscanf(buf, " %511[^\n\t =] = %511[^\n \t]", option, value) == 2) {
             std::string optStr(option);
@@ -211,26 +263,22 @@ void print_msg_flags(VkFlags msgFlags, char *msg_flags) {
         separator = true;
     }
     if (msgFlags & VK_DEBUG_REPORT_INFORMATION_BIT_EXT) {
-        if (separator)
-            strcat(msg_flags, ",");
+        if (separator) strcat(msg_flags, ",");
         strcat(msg_flags, "INFO");
         separator = true;
     }
     if (msgFlags & VK_DEBUG_REPORT_WARNING_BIT_EXT) {
-        if (separator)
-            strcat(msg_flags, ",");
+        if (separator) strcat(msg_flags, ",");
         strcat(msg_flags, "WARN");
         separator = true;
     }
     if (msgFlags & VK_DEBUG_REPORT_PERFORMANCE_WARNING_BIT_EXT) {
-        if (separator)
-            strcat(msg_flags, ",");
+        if (separator) strcat(msg_flags, ",");
         strcat(msg_flags, "PERF");
         separator = true;
     }
     if (msgFlags & VK_DEBUG_REPORT_ERROR_BIT_EXT) {
-        if (separator)
-            strcat(msg_flags, ",");
+        if (separator) strcat(msg_flags, ",");
         strcat(msg_flags, "ERROR");
     }
 }
