@@ -1,8 +1,8 @@
 #!/usr/bin/env python3
-# Copyright (c) 2015-2016 The Khronos Group Inc.
-# Copyright (c) 2015-2016 Valve Corporation
-# Copyright (c) 2015-2016 LunarG, Inc.
-# Copyright (c) 2015-2016 Google Inc.
+# Copyright (c) 2015-2017 The Khronos Group Inc.
+# Copyright (c) 2015-2017 Valve Corporation
+# Copyright (c) 2015-2017 LunarG, Inc.
+# Copyright (c) 2015-2017 Google Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -49,7 +49,7 @@ layer_source_files = [
 'descriptor_sets.cpp',
 'parameter_validation.cpp',
 'object_tracker.cpp',
-'image.cpp',
+'buffer_validation.cpp',
 'swapchain.cpp'
 ]
 header_file = 'vk_validation_error_messages.h'
@@ -88,6 +88,7 @@ class ValidationDatabase:
         self.db_implemented_enums = [] # list of all error enums claiming to be implemented in database file
         self.db_unimplemented_implicit = [] # list of all implicit checks that aren't marked implemented
         self.db_enum_to_tests = {} # dict where enum is key to lookup list of tests implementing the enum
+        self.db_invalid_implemented = [] # list of checks with invalid check_implemented flags
         #self.src_implemented_enums
     def read(self):
         """Read a database file into internal data structures, format of each line is <enum><implemented Y|N?><testname><api><errormsg><notes>"""
@@ -119,6 +120,8 @@ class ValidationDatabase:
                     self.db_implemented_enums.append(error_enum)
                 elif 'implicit' in note: # only make note of non-implemented implicit checks
                     self.db_unimplemented_implicit.append(error_enum)
+                if implemented not in ['Y', 'N']:
+                    self.db_invalid_implemented.append(error_enum)
                 if testname.lower() not in ['unknown', 'none']:
                     self.db_enum_to_tests[error_enum] = testname.split(',')
                     #if len(self.db_enum_to_tests[error_enum]) > 1:
@@ -287,12 +290,23 @@ def main(argv=None):
     # Process stats - Just doing this inline in main, could make a fancy class to handle
     #   all the processing of data and then get results from that
     txt_color = bcolors()
+
     print("Validation Statistics")
     # First give number of checks in db & header and report any discrepancies
     db_enums = len(val_db.db_dict.keys())
     hdr_enums = len(val_header.enums)
     print(" Database file includes %d unique checks" % (db_enums))
     print(" Header file declares %d unique checks" % (hdr_enums))
+
+    # Report any checks that have an invalid check_implemented flag
+    if len(val_db.db_invalid_implemented) > 0:
+        result = 1
+        print(txt_color.red() + "The following checks have an invalid check_implemented flag (must be 'Y' or 'N'):" + txt_color.endc())
+        for invalid_imp_enum in val_db.db_invalid_implemented:
+            check_implemented = val_db.db_dict[invalid_imp_enum]['check_implemented']
+            print(txt_color.red() + "    %s has check_implemented flag '%s'" % (invalid_imp_enum, check_implemented) + txt_color.endc())
+
+    # Report details about how well the Database and Header are synchronized.
     tmp_db_dict = val_db.db_dict
     db_missing = []
     for enum in val_header.enums:
@@ -311,6 +325,7 @@ def main(argv=None):
             print(txt_color.red() + "   The following checks are in database but haven't been declared in the header:" + txt_color.endc())
             for extra_enum in tmp_db_dict:
                 print(txt_color.red() + "    %s" % (extra_enum) + txt_color.endc())
+
     # Report out claimed implemented checks vs. found actual implemented checks
     imp_not_found = [] # Checks claimed to implemented in DB file but no source found
     imp_not_claimed = [] # Checks found implemented but not claimed to be in DB
@@ -324,6 +339,7 @@ def main(argv=None):
         if src_enum not in val_db.db_implemented_enums:
             imp_not_claimed.append(src_enum)
     print(" Database file claims that %d checks (%s) are implemented in source." % (len(val_db.db_implemented_enums), "{0:.0f}%".format(float(len(val_db.db_implemented_enums))/db_enums * 100)))
+
     if len(val_db.db_unimplemented_implicit) > 0:
         print(" Database file claims %d implicit checks (%s) that are not implemented." % (len(val_db.db_unimplemented_implicit), "{0:.0f}%".format(float(len(val_db.db_unimplemented_implicit))/db_enums * 100)))
         total_checks = len(val_db.db_implemented_enums) + len(val_db.db_unimplemented_implicit)
@@ -341,6 +357,7 @@ def main(argv=None):
             print(txt_color.red() + "   The following checks are implemented in source, but not claimed to be in Database:" + txt_color.endc())
             for imp_enum in imp_not_claimed:
                 print(txt_color.red() + "    %s" % (imp_enum) + txt_color.endc())
+
     if multiple_uses:
         print(txt_color.yellow() + "  Note that some checks are used multiple times. These may be good candidates for new valid usage spec language." + txt_color.endc())
         print(txt_color.yellow() + "  Here is a list of each check used multiple times with its number of uses:" + txt_color.endc())
@@ -349,6 +366,7 @@ def main(argv=None):
                 print(txt_color.yellow() + "   %s: %d uses in file,line:" % (enum, val_source.enum_count_dict[enum]['count']) + txt_color.endc())
                 for file_line in val_source.enum_count_dict[enum]['file_line']:
                     print(txt_color.yellow() + "   \t%s" % (file_line) + txt_color.endc())
+
     # Now check that tests claimed to be implemented are actual test names
     bad_testnames = []
     tests_missing_enum = {} # Report tests that don't use validation error enum to check for error case
@@ -373,6 +391,7 @@ def main(argv=None):
             print(txt_color.yellow() + "   Testname %s does not explicitly check for these ids:" % (testname) + txt_color.endc())
             for enum in tests_missing_enum[testname]:
                 print(txt_color.yellow() + "    %s" % (enum) + txt_color.endc())
+
     # TODO : Go through all enums found in the test file and make sure they're correctly documented in the database file
     print(" Database file claims that %d checks have tests written." % len(val_db.db_enum_to_tests))
     if len(bad_testnames) == 0:
