@@ -1,7 +1,7 @@
 /*
- * Copyright (c) 2015-2016 The Khronos Group Inc.
- * Copyright (c) 2015-2016 Valve Corporation
- * Copyright (c) 2015-2016 LunarG, Inc.
+ * Copyright (c) 2015-2017 The Khronos Group Inc.
+ * Copyright (c) 2015-2017 Valve Corporation
+ * Copyright (c) 2015-2017 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -35,7 +35,7 @@ class VkImageObj;
 using namespace std;
 
 class VkDeviceObj : public vk_testing::Device {
-  public:
+   public:
     VkDeviceObj(uint32_t id, VkPhysicalDevice obj);
     VkDeviceObj(uint32_t id, VkPhysicalDevice obj, std::vector<const char *> &extension_names,
                 VkPhysicalDeviceFeatures *features = nullptr);
@@ -54,7 +54,7 @@ class VkCommandBufferObj;
 class VkDepthStencilObj;
 
 class VkRenderFramework : public VkTestFramework {
-  public:
+   public:
     VkRenderFramework();
     ~VkRenderFramework();
 
@@ -75,11 +75,12 @@ class VkRenderFramework : public VkTestFramework {
                        void *userData = NULL);
 
     void ShutdownFramework();
-    void InitState(VkPhysicalDeviceFeatures *features = nullptr);
+    void GetPhysicalDeviceFeatures(VkPhysicalDeviceFeatures *features);
+    void InitState(VkPhysicalDeviceFeatures *features = nullptr, const VkCommandPoolCreateFlags flags = 0);
 
     const VkRenderPassBeginInfo &renderPassBeginInfo() const { return m_renderPassBeginInfo; }
 
-  protected:
+   protected:
     VkApplicationInfo app_info;
     VkInstance inst;
     VkPhysicalDevice objs[16];
@@ -145,7 +146,7 @@ class VkPipelineObj;
 class VkDescriptorSetObj;
 
 class VkCommandBufferObj : public vk_testing::CommandBuffer {
-  public:
+   public:
     VkCommandBufferObj(VkDeviceObj *device, VkCommandPool pool);
     VkCommandBuffer GetBufferHandle();
     VkResult BeginCommandBuffer();
@@ -191,13 +192,13 @@ class VkCommandBufferObj : public vk_testing::CommandBuffer {
     void ClearDepthStencilImage(VkImage image, VkImageLayout imageLayout, const VkClearDepthStencilValue *pColor,
                                 uint32_t rangeCount, const VkImageSubresourceRange *pRanges);
 
-  protected:
+   protected:
     VkDeviceObj *m_device;
     vector<VkImageObj *> m_renderTargets;
 };
 
 class VkConstantBufferObj : public vk_testing::Buffer {
-  public:
+   public:
     VkConstantBufferObj(VkDeviceObj *device,
                         VkBufferUsageFlags usage = VK_BUFFER_USAGE_TRANSFER_SRC_BIT | VK_BUFFER_USAGE_TRANSFER_DST_BIT);
     VkConstantBufferObj(VkDeviceObj *device, int constantCount, int constantSize, const void *data,
@@ -216,7 +217,7 @@ class VkConstantBufferObj : public vk_testing::Buffer {
 
     VkDescriptorBufferInfo m_descriptorBufferInfo;
 
-  protected:
+   protected:
     VkDeviceObj *m_device;
     vk_testing::BufferView m_bufferView;
     int m_numVertices;
@@ -227,33 +228,33 @@ class VkConstantBufferObj : public vk_testing::Buffer {
 };
 
 class VkIndexBufferObj : public VkConstantBufferObj {
-  public:
+   public:
     VkIndexBufferObj(VkDeviceObj *device);
     void CreateAndInitBuffer(int numIndexes, VkIndexType dataFormat, const void *data);
     void Bind(VkCommandBuffer commandBuffer, VkDeviceSize offset);
     VkIndexType GetIndexType();
 
-  protected:
+   protected:
     VkIndexType m_indexType;
 };
 
 class VkRenderpassObj {
-  public:
+   public:
     VkRenderpassObj(VkDeviceObj *device);
     ~VkRenderpassObj();
     VkRenderPass handle() { return m_renderpass; }
 
-  protected:
+   protected:
     VkRenderPass m_renderpass;
     VkDevice device;
 };
 
 class VkImageObj : public vk_testing::Image {
-  public:
+   public:
     VkImageObj(VkDeviceObj *dev);
     bool IsCompatible(VkFlags usage, VkFlags features);
 
-  public:
+   public:
     void init(uint32_t w, uint32_t h, VkFormat fmt, VkFlags usage, VkImageTiling tiling = VK_IMAGE_TILING_LINEAR,
               VkMemoryPropertyFlags reqs = 0);
 
@@ -303,7 +304,7 @@ class VkImageObj : public vk_testing::Image {
     uint32_t height() const { return extent().height; }
     VkDeviceObj *device() const { return m_device; }
 
-  protected:
+   protected:
     VkDeviceObj *m_device;
 
     vk_testing::ImageView m_targetView;
@@ -311,26 +312,26 @@ class VkImageObj : public vk_testing::Image {
 };
 
 class VkTextureObj : public VkImageObj {
-  public:
+   public:
     VkTextureObj(VkDeviceObj *device, uint32_t *colors = NULL);
 
     VkDescriptorImageInfo m_imageInfo;
 
-  protected:
+   protected:
     VkDeviceObj *m_device;
     vk_testing::ImageView m_textureView;
     VkDeviceSize m_rowPitch;
 };
 
 class VkDepthStencilObj : public VkImageObj {
-  public:
+   public:
     VkDepthStencilObj(VkDeviceObj *device);
     void Init(VkDeviceObj *device, int32_t width, int32_t height, VkFormat format,
               VkImageUsageFlags usage = VK_IMAGE_USAGE_DEPTH_STENCIL_ATTACHMENT_BIT);
     bool Initialized();
     VkImageView *BindInfo();
 
-  protected:
+   protected:
     VkDeviceObj *m_device;
     bool m_initialized;
     vk_testing::ImageView m_imageView;
@@ -339,15 +340,15 @@ class VkDepthStencilObj : public VkImageObj {
 };
 
 class VkSamplerObj : public vk_testing::Sampler {
-  public:
+   public:
     VkSamplerObj(VkDeviceObj *device);
 
-  protected:
+   protected:
     VkDeviceObj *m_device;
 };
 
 class VkDescriptorSetObj : public vk_testing::DescriptorPool {
-  public:
+   public:
     VkDescriptorSetObj(VkDeviceObj *device);
     ~VkDescriptorSetObj();
 
@@ -360,7 +361,7 @@ class VkDescriptorSetObj : public vk_testing::DescriptorPool {
     VkPipelineLayout GetPipelineLayout() const;
     int GetTypeCounts() { return m_type_counts.size(); }
 
-  protected:
+   protected:
     VkDeviceObj *m_device;
     std::vector<VkDescriptorSetLayoutBinding> m_layout_bindings;
     std::map<VkDescriptorType, int> m_type_counts;
@@ -375,12 +376,12 @@ class VkDescriptorSetObj : public vk_testing::DescriptorPool {
 };
 
 class VkShaderObj : public vk_testing::ShaderModule {
-  public:
+   public:
     VkShaderObj(VkDeviceObj *device, const char *shaderText, VkShaderStageFlagBits stage, VkRenderFramework *framework,
                 char const *name = "main");
     VkPipelineShaderStageCreateInfo GetStageCreateInfo() const;
 
-  protected:
+   protected:
     VkPipelineShaderStageCreateInfo stage_info;
     VkShaderStageFlagBits m_stage;
     char const *m_name;
@@ -388,7 +389,7 @@ class VkShaderObj : public vk_testing::ShaderModule {
 };
 
 class VkPipelineObj : public vk_testing::Pipeline {
-  public:
+   public:
     VkPipelineObj(VkDeviceObj *device);
     void AddShader(VkShaderObj *shaderObj);
     void AddVertexInputAttribs(VkVertexInputAttributeDescription *vi_attrib, uint32_t count);
@@ -410,9 +411,12 @@ class VkPipelineObj : public vk_testing::Pipeline {
     void SetTessellation(const VkPipelineTessellationStateCreateInfo *te_state);
     void SetViewport(const vector<VkViewport> viewports);
     void SetScissor(const vector<VkRect2D> scissors);
-    VkResult CreateVKPipeline(VkPipelineLayout layout, VkRenderPass render_pass);
 
-  protected:
+    void InitGraphicsPipelineCreateInfo(VkGraphicsPipelineCreateInfo *gp_ci);
+
+    VkResult CreateVKPipeline(VkPipelineLayout layout, VkRenderPass render_pass, VkGraphicsPipelineCreateInfo *gp_ci = nullptr);
+
+   protected:
     VkPipelineVertexInputStateCreateInfo m_vi_state;
     VkPipelineInputAssemblyStateCreateInfo m_ia_state;
     VkPipelineRasterizationStateCreateInfo m_rs_state;
@@ -421,6 +425,7 @@ class VkPipelineObj : public vk_testing::Pipeline {
     VkPipelineViewportStateCreateInfo m_vp_state;
     VkPipelineMultisampleStateCreateInfo m_ms_state;
     VkPipelineTessellationStateCreateInfo m_te_state;
+    VkPipelineDynamicStateCreateInfo m_pd_state;
     vector<VkDynamicState> m_dynamic_state_enables;
     vector<VkViewport> m_viewports;
     vector<VkRect2D> m_scissors;
@@ -430,4 +435,4 @@ class VkPipelineObj : public vk_testing::Pipeline {
     vector<VkPipelineColorBlendAttachmentState> m_colorAttachments;
     int m_vertexBufferCount;
 };
-#endif // VKRENDERFRAMEWORK_H
+#endif  // VKRENDERFRAMEWORK_H
