@@ -3,24 +3,17 @@
  * Copyright (c) 2015-2016 Valve Corporation
  * Copyright (c) 2015-2016 LunarG, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and/or associated documentation files (the "Materials"), to
- * deal in the Materials without restriction, including without limitation the
- * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
- * sell copies of the Materials, and to permit persons to whom the Materials are
- * furnished to do so, subject to the following conditions:
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * The above copyright notice(s) and this permission notice shall be included in
- * all copies or substantial portions of the Materials.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * THE MATERIALS ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
- *
- * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
- * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
- * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE MATERIALS OR THE
- * USE OR OTHER DEALINGS IN THE MATERIALS.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * Author: Chia-I Wu <olvaffe@gmail.com>
  * Author: Courtney Goeltzenleuchter <courtney@LunarG.com>
@@ -29,10 +22,21 @@
 
 #include "vktestframework.h"
 #include "vkrenderframework.h"
+
+// For versions prior to VS 2015, suppress the warning
+// caused by the inconsistent redefinition of snprintf
+// between a vulkan header and a glslang header.
+#if (defined(_MSC_VER) && _MSC_VER < 1900 /*vs2015*/)
+#pragma warning(push)
+#pragma warning(disable : 4005)
+#endif
 // TODO FIXME remove this once glslang doesn't define this
 #undef BadValue
 #include "SPIRV/GlslangToSpv.h"
 #include "SPIRV/SPVRemapper.h"
+#if (defined(_MSC_VER) && _MSC_VER < 1900 /*vs2015*/)
+#pragma warning(pop)
+#endif
 #include <limits.h>
 #include <math.h>
 
@@ -41,39 +45,35 @@
 #endif
 
 #ifdef _WIN32
-#define ERR_EXIT(err_msg, err_class)                                           \
-    do {                                                                       \
-        MessageBox(NULL, err_msg, err_class, MB_OK);                           \
-        exit(1);                                                               \
+#define ERR_EXIT(err_msg, err_class)                 \
+    do {                                             \
+        MessageBox(NULL, err_msg, err_class, MB_OK); \
+        exit(1);                                     \
     } while (0)
-#else // _WIN32
+#else  // _WIN32
 
-#define ERR_EXIT(err_msg, err_class)                                           \
-    do {                                                                       \
-        printf(err_msg);                                                       \
-        fflush(stdout);                                                        \
-        exit(1);                                                               \
+#define ERR_EXIT(err_msg, err_class) \
+    do {                             \
+        printf(err_msg);             \
+        fflush(stdout);              \
+        exit(1);                     \
     } while (0)
-#endif // _WIN32
+#endif  // _WIN32
 
-#define GET_INSTANCE_PROC_ADDR(inst, entrypoint)                               \
-    {                                                                          \
-        m_fp##entrypoint =                                                     \
-            (PFN_vk##entrypoint)vkGetInstanceProcAddr(inst, "vk" #entrypoint); \
-        if (m_fp##entrypoint == NULL) {                                        \
-            ERR_EXIT("vkGetInstanceProcAddr failed to find vk" #entrypoint,    \
-                     "vkGetInstanceProcAddr Failure");                         \
-        }                                                                      \
+#define GET_INSTANCE_PROC_ADDR(inst, entrypoint)                                                              \
+    {                                                                                                         \
+        m_fp##entrypoint = (PFN_vk##entrypoint)vkGetInstanceProcAddr(inst, "vk" #entrypoint);                 \
+        if (m_fp##entrypoint == NULL) {                                                                       \
+            ERR_EXIT("vkGetInstanceProcAddr failed to find vk" #entrypoint, "vkGetInstanceProcAddr Failure"); \
+        }                                                                                                     \
     }
 
-#define GET_DEVICE_PROC_ADDR(dev, entrypoint)                                  \
-    {                                                                          \
-        m_fp##entrypoint =                                                     \
-            (PFN_vk##entrypoint)vkGetDeviceProcAddr(dev, "vk" #entrypoint);    \
-        if (m_fp##entrypoint == NULL) {                                        \
-            ERR_EXIT("vkGetDeviceProcAddr failed to find vk" #entrypoint,      \
-                     "vkGetDeviceProcAddr Failure");                           \
-        }                                                                      \
+#define GET_DEVICE_PROC_ADDR(dev, entrypoint)                                                             \
+    {                                                                                                     \
+        m_fp##entrypoint = (PFN_vk##entrypoint)vkGetDeviceProcAddr(dev, "vk" #entrypoint);                \
+        if (m_fp##entrypoint == NULL) {                                                                   \
+            ERR_EXIT("vkGetDeviceProcAddr failed to find vk" #entrypoint, "vkGetDeviceProcAddr Failure"); \
+        }                                                                                                 \
     }
 
 // Command-line options
@@ -94,11 +94,11 @@ enum TOptions {
     EOptionDefaultDesktop = 0x1000,
 };
 
-typedef struct _SwapchainBuffers {
+struct SwapchainBuffers {
     VkImage image;
     VkCommandBuffer cmd;
     VkImageView view;
-} SwapchainBuffers;
+};
 
 #ifndef _WIN32
 
@@ -135,8 +135,7 @@ void TestEnvironment::SetUp() {
 
 void TestEnvironment::TearDown() { glslang::FinalizeProcess(); }
 
-VkTestFramework::VkTestFramework()
-    : m_compile_options(0), m_num_shader_strings(0) {}
+VkTestFramework::VkTestFramework() : m_compile_options(0), m_num_shader_strings(0) {}
 
 VkTestFramework::~VkTestFramework() {}
 
@@ -167,12 +166,14 @@ void VkTestFramework::InitArgs(int *argc, char *argv[]) {
             m_canonicalize_spv = true;
         else if (optionMatch("--help", argv[i]) || optionMatch("-h", argv[i])) {
             printf("\nOther options:\n");
-            printf("\t--show-images\n"
-                   "\t\tDisplay test images in viewer after tests complete.\n");
-            printf("\t--save-images\n"
-                   "\t\tSave tests images as ppm files in current working "
-                   "directory.\n"
-                   "\t\tUsed to generate golden images for compare-images.\n");
+            printf(
+                "\t--show-images\n"
+                "\t\tDisplay test images in viewer after tests complete.\n");
+            printf(
+                "\t--save-images\n"
+                "\t\tSave tests images as ppm files in current working "
+                "directory.\n"
+                "\t\tUsed to generate golden images for compare-images.\n");
             printf(
                 "\t--compare-images\n"
                 "\t\tCompare test images to 'golden' image in golden folder.\n"
@@ -186,9 +187,10 @@ void VkTestFramework::InitArgs(int *argc, char *argv[]) {
             printf(
                 "\t--no-SPV\n"
                 "\t\tUse built-in GLSL compiler rather than SPV code path.\n");
-            printf("\t--strip-SPV\n"
-                   "\t\tStrip SPIR-V debug information (line numbers, names, "
-                   "etc).\n");
+            printf(
+                "\t--strip-SPV\n"
+                "\t\tStrip SPIR-V debug information (line numbers, names, "
+                "etc).\n");
             printf(
                 "\t--canonicalize-SPV\n"
                 "\t\tRemap SPIR-V ids before submission to aid compression.\n");
@@ -209,29 +211,23 @@ void VkTestFramework::InitArgs(int *argc, char *argv[]) {
     }
 }
 
-VkFormat VkTestFramework::GetFormat(VkInstance instance,
-                                    vk_testing::Device *device) {
+VkFormat VkTestFramework::GetFormat(VkInstance instance, vk_testing::Device *device) {
     VkFormatProperties format_props;
 
-    vkGetPhysicalDeviceFormatProperties(
-        device->phy().handle(), VK_FORMAT_B8G8R8A8_UNORM, &format_props);
-    if (format_props.linearTilingFeatures &
-            VK_FORMAT_FEATURE_COLOR_ATTACHMENT_BIT ||
-        format_props.optimalTilingFeatures &
-            VK_FORMAT_FEATURE_COLOR_ATTACHMENT_BIT) {
+    vkGetPhysicalDeviceFormatProperties(device->phy().handle(), VK_FORMAT_B8G8R8A8_UNORM, &format_props);
+    if (format_props.linearTilingFeatures & VK_FORMAT_FEATURE_COLOR_ATTACHMENT_BIT ||
+        format_props.optimalTilingFeatures & VK_FORMAT_FEATURE_COLOR_ATTACHMENT_BIT) {
         return VK_FORMAT_B8G8R8A8_UNORM;
     }
-    vkGetPhysicalDeviceFormatProperties(
-        device->phy().handle(), VK_FORMAT_R8G8B8A8_UNORM, &format_props);
-    if (format_props.linearTilingFeatures &
-            VK_FORMAT_FEATURE_COLOR_ATTACHMENT_BIT ||
-        format_props.optimalTilingFeatures &
-            VK_FORMAT_FEATURE_COLOR_ATTACHMENT_BIT) {
+    vkGetPhysicalDeviceFormatProperties(device->phy().handle(), VK_FORMAT_R8G8B8A8_UNORM, &format_props);
+    if (format_props.linearTilingFeatures & VK_FORMAT_FEATURE_COLOR_ATTACHMENT_BIT ||
+        format_props.optimalTilingFeatures & VK_FORMAT_FEATURE_COLOR_ATTACHMENT_BIT) {
         return VK_FORMAT_R8G8B8A8_UNORM;
     }
-    printf("Error - device does not support VK_FORMAT_B8G8R8A8_UNORM nor "
-           "VK_FORMAT_R8G8B8A8_UNORM - exiting\n");
-    exit(0);
+    printf(
+        "Error - device does not support VK_FORMAT_B8G8R8A8_UNORM nor "
+        "VK_FORMAT_R8G8B8A8_UNORM - exiting\n");
+    exit(1);
 }
 
 void VkTestFramework::Finish() {}
@@ -340,8 +336,7 @@ static const char *DefaultConfig =
 // *.conf => this is a config file that can set limits/resources
 //
 bool VkTestFramework::SetConfigFile(const std::string &name) {
-    if (name.size() < 5)
-        return false;
+    if (name.size() < 5) return false;
 
     if (name.compare(name.size() - 5, 5, ".conf") == 0) {
         ConfigFile = name;
@@ -362,8 +357,9 @@ void VkTestFramework::ProcessConfigFile() {
         if (configStrings)
             config = *configStrings;
         else {
-            printf("Error opening configuration file; will instead use the "
-                   "default configuration\n");
+            printf(
+                "Error opening configuration file; will instead use the "
+                "default configuration\n");
         }
     }
 
@@ -376,12 +372,11 @@ void VkTestFramework::ProcessConfigFile() {
     const char *token = strtok(config, delims);
     while (token) {
         const char *valueStr = strtok(0, delims);
-        if (valueStr == 0 ||
-            !(valueStr[0] == '-' ||
-              (valueStr[0] >= '0' && valueStr[0] <= '9'))) {
-            printf("Error: '%s' bad .conf file.  Each name must be followed by "
-                   "one number.\n",
-                   valueStr ? valueStr : "");
+        if (valueStr == 0 || !(valueStr[0] == '-' || (valueStr[0] >= '0' && valueStr[0] <= '9'))) {
+            printf(
+                "Error: '%s' bad .conf file.  Each name must be followed by "
+                "one number.\n",
+                valueStr ? valueStr : "");
             return;
         }
         int value = atoi(valueStr);
@@ -544,8 +539,7 @@ void VkTestFramework::ProcessConfigFile() {
             Resources.maxAtomicCounterBufferSize = value;
         else if (strcmp(token, "MaxTransformFeedbackBuffers") == 0)
             Resources.maxTransformFeedbackBuffers = value;
-        else if (strcmp(token, "MaxTransformFeedbackInterleavedComponents") ==
-                 0)
+        else if (strcmp(token, "MaxTransformFeedbackInterleavedComponents") == 0)
             Resources.maxTransformFeedbackInterleavedComponents = value;
         else if (strcmp(token, "MaxCullDistances") == 0)
             Resources.maxCullDistances = value;
@@ -563,8 +557,7 @@ void VkTestFramework::ProcessConfigFile() {
         else if (strcmp(token, "generalUniformIndexing") == 0)
             Resources.limits.generalUniformIndexing = (value != 0);
         else if (strcmp(token, "generalAttributeMatrixVectorIndexing") == 0)
-            Resources.limits.generalAttributeMatrixVectorIndexing =
-                (value != 0);
+            Resources.limits.generalAttributeMatrixVectorIndexing = (value != 0);
         else if (strcmp(token, "generalVaryingIndexing") == 0)
             Resources.limits.generalVaryingIndexing = (value != 0);
         else if (strcmp(token, "generalSamplerIndexing") == 0)
@@ -574,22 +567,17 @@ void VkTestFramework::ProcessConfigFile() {
         else if (strcmp(token, "generalConstantMatrixVectorIndexing") == 0)
             Resources.limits.generalConstantMatrixVectorIndexing = (value != 0);
         else
-            printf("Warning: unrecognized limit (%s) in configuration file.\n",
-                   token);
+            printf("Warning: unrecognized limit (%s) in configuration file.\n", token);
 
         token = strtok(0, delims);
     }
-    if (configStrings)
-        FreeFileData(configStrings);
+    if (configStrings) FreeFileData(configStrings);
 }
 
 void VkTestFramework::SetMessageOptions(EShMessages &messages) {
-    if (m_compile_options & EOptionRelaxedErrors)
-        messages = (EShMessages)(messages | EShMsgRelaxedErrors);
-    if (m_compile_options & EOptionIntermediate)
-        messages = (EShMessages)(messages | EShMsgAST);
-    if (m_compile_options & EOptionSuppressWarnings)
-        messages = (EShMessages)(messages | EShMsgSuppressWarnings);
+    if (m_compile_options & EOptionRelaxedErrors) messages = (EShMessages)(messages | EShMsgRelaxedErrors);
+    if (m_compile_options & EOptionIntermediate) messages = (EShMessages)(messages | EShMsgAST);
+    if (m_compile_options & EOptionSuppressWarnings) messages = (EShMessages)(messages | EShMsgSuppressWarnings);
 }
 
 //
@@ -605,18 +593,16 @@ char **VkTestFramework::ReadFileData(const char *fileName) {
 #endif
 
     char *fdata;
-    int count = 0;
+    size_t count = 0;
     const int maxSourceStrings = 5;
-    char **return_data =
-        (char **)malloc(sizeof(char *) * (maxSourceStrings + 1));
+    char **return_data = (char **)malloc(sizeof(char *) * (maxSourceStrings + 1));
 
     if (errorCode) {
         printf("Error: unable to open input file: %s\n", fileName);
         return 0;
     }
 
-    while (fgetc(in) != EOF)
-        count++;
+    while (fgetc(in) != EOF) count++;
 
     fseek(in, 0, SEEK_SET);
 
@@ -638,8 +624,8 @@ char **VkTestFramework::ReadFileData(const char *fileName) {
     } else
         m_num_shader_strings = 1;
 
-    int len = (int)(ceil)((float)count / (float)m_num_shader_strings);
-    int ptr_len = 0, i = 0;
+    size_t len = (int)(ceil)((float)count / (float)m_num_shader_strings);
+    size_t ptr_len = 0, i = 0;
     while (count > 0) {
         return_data[i] = (char *)malloc(len + 2);
         memcpy(return_data[i], fdata + ptr_len, len);
@@ -659,8 +645,7 @@ char **VkTestFramework::ReadFileData(const char *fileName) {
 }
 
 void VkTestFramework::FreeFileData(char **data) {
-    for (int i = 0; i < m_num_shader_strings; i++)
-        free(data[i]);
+    for (int i = 0; i < m_num_shader_strings; i++) free(data[i]);
 }
 
 //
@@ -700,29 +685,28 @@ EShLanguage VkTestFramework::FindLanguage(const std::string &name) {
 //
 // Convert VK shader type to compiler's
 //
-EShLanguage
-VkTestFramework::FindLanguage(const VkShaderStageFlagBits shader_type) {
+EShLanguage VkTestFramework::FindLanguage(const VkShaderStageFlagBits shader_type) {
     switch (shader_type) {
-    case VK_SHADER_STAGE_VERTEX_BIT:
-        return EShLangVertex;
+        case VK_SHADER_STAGE_VERTEX_BIT:
+            return EShLangVertex;
 
-    case VK_SHADER_STAGE_TESSELLATION_CONTROL_BIT:
-        return EShLangTessControl;
+        case VK_SHADER_STAGE_TESSELLATION_CONTROL_BIT:
+            return EShLangTessControl;
 
-    case VK_SHADER_STAGE_TESSELLATION_EVALUATION_BIT:
-        return EShLangTessEvaluation;
+        case VK_SHADER_STAGE_TESSELLATION_EVALUATION_BIT:
+            return EShLangTessEvaluation;
 
-    case VK_SHADER_STAGE_GEOMETRY_BIT:
-        return EShLangGeometry;
+        case VK_SHADER_STAGE_GEOMETRY_BIT:
+            return EShLangGeometry;
 
-    case VK_SHADER_STAGE_FRAGMENT_BIT:
-        return EShLangFragment;
+        case VK_SHADER_STAGE_FRAGMENT_BIT:
+            return EShLangFragment;
 
-    case VK_SHADER_STAGE_COMPUTE_BIT:
-        return EShLangCompute;
+        case VK_SHADER_STAGE_COMPUTE_BIT:
+            return EShLangCompute;
 
-    default:
-        return EShLangVertex;
+        default:
+            return EShLangVertex;
     }
 }
 
@@ -730,9 +714,7 @@ VkTestFramework::FindLanguage(const VkShaderStageFlagBits shader_type) {
 // Compile a given string containing GLSL into SPV for use by VK
 // Return value of false means an error was encountered.
 //
-bool VkTestFramework::GLSLtoSPV(const VkShaderStageFlagBits shader_type,
-                                const char *pshader,
-                                std::vector<unsigned int> &spirv) {
+bool VkTestFramework::GLSLtoSPV(const VkShaderStageFlagBits shader_type, const char *pshader, std::vector<unsigned int> &spirv) {
     glslang::TProgram program;
     const char *shaderStrings[1];
 
@@ -744,8 +726,7 @@ bool VkTestFramework::GLSLtoSPV(const VkShaderStageFlagBits shader_type,
 
     EShMessages messages = EShMsgDefault;
     SetMessageOptions(messages);
-    messages =
-        static_cast<EShMessages>(messages | EShMsgSpvRules | EShMsgVulkanRules);
+    messages = static_cast<EShMessages>(messages | EShMsgSpvRules | EShMsgVulkanRules);
 
     EShLanguage stage = FindLanguage(shader_type);
     glslang::TShader *shader = new glslang::TShader(stage);
@@ -753,16 +734,13 @@ bool VkTestFramework::GLSLtoSPV(const VkShaderStageFlagBits shader_type,
     shaderStrings[0] = pshader;
     shader->setStrings(shaderStrings, 1);
 
-    if (!shader->parse(&Resources,
-                       (m_compile_options & EOptionDefaultDesktop) ? 110 : 100,
-                       false, messages)) {
-
+    if (!shader->parse(&Resources, (m_compile_options & EOptionDefaultDesktop) ? 110 : 100, false, messages)) {
         if (!(m_compile_options & EOptionSuppressInfolog)) {
             puts(shader->getInfoLog());
             puts(shader->getInfoDebugLog());
         }
 
-        return false; // something didn't work
+        return false;  // something didn't work
     }
 
     program.addShader(shader);
@@ -772,7 +750,6 @@ bool VkTestFramework::GLSLtoSPV(const VkShaderStageFlagBits shader_type,
     //
 
     if (!program.link(messages)) {
-
         if (!(m_compile_options & EOptionSuppressInfolog)) {
             puts(shader->getInfoLog());
             puts(shader->getInfoDebugLog());
